@@ -1,9 +1,7 @@
+# frozen_string_literal: true
+
 module Regexp::Expression
   class PosixClass < Regexp::Expression::Base
-    def negative?
-      type == :nonposixclass
-    end
-
     def name
       text[/\w+/]
     end
